import {Component, HostListener, ViewChild} from '@angular/core'
import {FormControl, Validators} from '@angular/forms'
import {ErrorHandlingComponent} from '../shared/components/subscribing.component'
import {AccountService} from './services/account.service'
import {AppState} from '../shared/app-state'
import {ErrorHandler, ErrorService} from '../shared/service/error.service'
import {ActivatedRoute, Router} from '@angular/router'
import {CreForm, ICreForm} from "../shared/components/forms/forms";
import {take, takeUntil} from "rxjs/operators";
import {AlertService} from "../shared/service/alert.service";

@Component({
  selector: 'cre-login',
  templateUrl: 'login.html',
  styles: [
    'cre-form { min-width: 25rem; margin-top: 50vh; transform: translateY(-70%) }'
  ]
})
export class Login extends ErrorHandlingComponent {
  @ViewChild(CreForm) form: ICreForm

  userIdControl = new FormControl(null, Validators.compose([Validators.required, Validators.pattern(new RegExp('^[0-9]+$'))]))
  passwordControl = new FormControl(null, Validators.required)

  errorHandlers: ErrorHandler[] = [{
    filter: error => error.status === 403,
    messageProducer: () => 'Les identifiants entrés sont invalides'
  }]

  constructor(
    private accountService: AccountService,
    private alertService: AlertService,
    private appState: AppState,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
    this.appState.title = 'Connexion'
  }

  // Allows to send the form by pressing Enter
  @HostListener('window:keyup.enter', ['$event'])
  onEnterKeyEvent() {
    if (this.form.formGroup) {
      this.submit()
    }
  }

  submit() {
    this.subscribeAndNavigate(
      this.accountService.login(this.userIdControl.value, this.passwordControl.value),
      '/color/list'
    )
  }

  get controls(): { userId: FormControl, password: FormControl } {
    return {
      userId: this.userIdControl,
      password: this.passwordControl
    }
  }
}
